@@ -42,7 +42,7 @@ enum speedOfAAlias { none,fast,slow};
 */
 
 class KNutAnalog : public TQFrame  {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
