@@ -26,10 +26,10 @@
 #include <tqdatetime.h>
 #include <tqmutex.h>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <ksimpleconfig.h>
 
-#include <kwin.h>
+#include <twin.h>
 
 #include <unistd.h>  // for function sleep and other ...
 
@@ -53,10 +53,10 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
   analogRecords = new KNutVarData();
 
   m_upsTimer = new TQTimer (this);
-  connect( m_upsTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotTimeout()) );
+  connect( m_upsTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotTimeout()) );
 
   m_reconnectTimer = new TQTimer(this);
-  connect( m_reconnectTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotReconnectTimeout()) );
+  connect( m_reconnectTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotReconnectTimeout()) );
 
 
   //  data for combo
@@ -71,16 +71,16 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
     m_myDock = new KNutDock(&m_mainUpsInfo,&settingData,upsRecords);
 
     m_myDock->show();
-    connect(m_myDock, TQT_SIGNAL(endApplication()), this, TQT_SLOT(slotExitApplication()));
-    connect(m_myDock, TQT_SIGNAL(activeMainWindow()), this, TQT_SLOT(slotActiveMainWindow()));
-    connect(m_myDock, TQT_SIGNAL(minimize()), this, TQT_SLOT(closeMainWindow()));
-    connect(m_myDock, TQT_SIGNAL(UPSChanged(TQString)), this, TQT_SLOT(slotSetNewUPS (TQString)));
+    connect(m_myDock, TQ_SIGNAL(endApplication()), this, TQ_SLOT(slotExitApplication()));
+    connect(m_myDock, TQ_SIGNAL(activeMainWindow()), this, TQ_SLOT(slotActiveMainWindow()));
+    connect(m_myDock, TQ_SIGNAL(minimize()), this, TQ_SLOT(closeMainWindow()));
+    connect(m_myDock, TQ_SIGNAL(UPSChanged(TQString)), this, TQ_SLOT(slotSetNewUPS (TQString)));
 
-    connect(m_myDock, TQT_SIGNAL(preferences()),this, TQT_SLOT(slotPreferenceUps()));
-    connect(m_myDock, TQT_SIGNAL(printUPSVars()),this, TQT_SLOT(slotPrintUPSVars()));
-    connect(m_myDock, TQT_SIGNAL(instComms()),this, TQT_SLOT(slotInstComms()));
-    connect(m_myDock, TQT_SIGNAL(RWVars()),this, TQT_SLOT(slotRWVars()));
-    connect(m_myDock, TQT_SIGNAL(makeRefreshConnection()),this, TQT_SLOT(slotRefreshConnection()));
+    connect(m_myDock, TQ_SIGNAL(preferences()),this, TQ_SLOT(slotPreferenceUps()));
+    connect(m_myDock, TQ_SIGNAL(printUPSVars()),this, TQ_SLOT(slotPrintUPSVars()));
+    connect(m_myDock, TQ_SIGNAL(instComms()),this, TQ_SLOT(slotInstComms()));
+    connect(m_myDock, TQ_SIGNAL(RWVars()),this, TQ_SLOT(slotRWVars()));
+    connect(m_myDock, TQ_SIGNAL(makeRefreshConnection()),this, TQ_SLOT(slotRefreshConnection()));
     }
 
   addEventString(i18n("Ready."));
@@ -99,11 +99,11 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
   m_mainUpsInfo.upsNet = new KNutNet( m_mainUpsInfo.record.upsAddress, m_mainUpsInfo.record.upsName, m_mainUpsInfo.record.port,5,200);
 
 
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(firstConnection(void)),this, TQT_SLOT(slotFirstConnection(void)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(connectionError(int)),this, TQT_SLOT(slotErrorConnection(int)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(connectionClosed(void )),this, TQT_SLOT(slotConnectionClosed(void)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(tryFirstConnection(int )),this, TQT_SLOT(slotTryFirstConnection(int)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(tryRepeatFirstConnection(int )),this, TQT_SLOT(slotTryReepatFirstConnection( int )));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(firstConnection(void)),this, TQ_SLOT(slotFirstConnection(void)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(connectionError(int)),this, TQ_SLOT(slotErrorConnection(int)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(connectionClosed(void )),this, TQ_SLOT(slotConnectionClosed(void)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(tryFirstConnection(int )),this, TQ_SLOT(slotTryFirstConnection(int)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(tryRepeatFirstConnection(int )),this, TQ_SLOT(slotTryReepatFirstConnection( int )));
 
 
 // state of connection to usbd, this isn't state of knutnet
@@ -151,7 +151,7 @@ KNutClient::~KNutClient(void) {
 
 
 void KNutClient::slotTryFirstConnection (int maxCount) {
-//qDebug ("KNutClient::slotTryFirstConnection");
+//tqDebug ("KNutClient::slotTryFirstConnection");
 
 //knutNet begin the first test of connection (connectToHost will be made after emiting signal tryFirstConnection )
 // repaints icon 
@@ -161,7 +161,7 @@ void KNutClient::slotTryFirstConnection (int maxCount) {
 
 
 void KNutClient::slotTryReepatFirstConnection (int number ) {
-//qDebug ("KNutClient::slotTryFirstConnection");
+//tqDebug ("KNutClient::slotTryFirstConnection");
 //knutNet begin nexts test of connection 
 
   if (mainWindow) mainWindow->setProgressConnectPB (number); 
@@ -170,7 +170,7 @@ void KNutClient::slotTryReepatFirstConnection (int number ) {
 
 
 void KNutClient::slotFirstConnection (void) {
-//qDebug ("sKNutClient::slotFirstConnection");
+//tqDebug ("sKNutClient::slotFirstConnection");
 //TCP - UDP connection to server was made
 
   bool reconnecting = m_mainUpsInfo.reconnecting;
@@ -224,7 +224,7 @@ void KNutClient::slotFirstConnection (void) {
 
     switch (m_mainUpsInfo.nutVariables) { // type of variables, old or new (with dot)
         case 1:
-//qDebug ("sKNutClient::slotFirstConnection - var 1");
+//tqDebug ("sKNutClient::slotFirstConnection - var 1");
           if (!(m_mainUpsInfo.upsNet->existName("BATT_RUNTIME"))) m_mainUpsInfo.runtimeVar="BATT_RUNTIME";
           else m_mainUpsInfo.runtimeVar="RUNTIME";
           m_mainUpsInfo.upsLoadVar="LOADPCT";
@@ -233,7 +233,7 @@ void KNutClient::slotFirstConnection (void) {
           m_mainUpsInfo.statusVar="STATUS";
         break;
         case 2:
-//qDebug ("sKNutClient::slotFirstConnection - var 2");
+//tqDebug ("sKNutClient::slotFirstConnection - var 2");
           m_mainUpsInfo.runtimeVar="battery.runtime";
           m_mainUpsInfo.upsLoadVar="ups.load";
           m_mainUpsInfo.lowxferVar="input.transfer.low";
@@ -264,7 +264,7 @@ void KNutClient::slotFirstConnection (void) {
 
 void KNutClient::slotErrorConnection (int error) {
 
-//qDebug ("KNutClient::slotErrorConnection (1)");
+//tqDebug ("KNutClient::slotErrorConnection (1)");
 
   if (mainWindow) mainWindow->hideConnectPB();
 
@@ -277,7 +277,7 @@ void KNutClient::slotErrorConnection (int error) {
   if (m_myDock) m_myDock->repaintDock(true);
 
   if (m_mainUpsInfo.reconnecting) {
-//qDebug ("KNutClient::slotErrorConnection (2)");
+//tqDebug ("KNutClient::slotErrorConnection (2)");
     m_mainUpsInfo.reconnectCount++;
     if (m_mainUpsInfo.reconnectCount > countNextConnDelay) m_mainUpsInfo.reconnectCount = countNextConnDelay;
 
@@ -285,7 +285,7 @@ void KNutClient::slotErrorConnection (int error) {
     m_reconnectTimer->start( nextConnDelay[m_mainUpsInfo.reconnectCount-1]*1000, TRUE ); // starts reconnect timer again
     }
   else {
-//qDebug ("KNutClient::slotErrorConnection (3)");
+//tqDebug ("KNutClient::slotErrorConnection (3)");
     addEventString (KNutVarData::errorToText(m_mainUpsInfo.netError),m_mainUpsInfo.record.name);
 //    KNutVarData::showError (mainUpsInfo.netError);
     if ((m_myMessMan)) m_myMessMan->addMessage(KNutVarData::errorToText(m_mainUpsInfo.netError),knc::errorLevel,true);
@@ -377,9 +377,9 @@ void KNutClient::initVars (void) {
   settingData.analogScaleColor=kapp->config()->readColorEntry ("AnalogScaleColor",& DEFAULT_SCALE_COLOR);
   settingData.analogFontColor=kapp->config()->readColorEntry ("AnalogFontColor",& DEFAULT_FONT_COLOR);
   settingData.toolTipFlags=kapp->config()->readUnsignedNumEntry("ToolTipFlags",KNutDock::DefaultToolTipFlags);
-  settingData.customKIconColor=kapp->config()->readBoolEntry("CustomKIconColor",FALSE);
-  settingData.kIconBackgroundColor=kapp->config()->readColorEntry ("KIconBackGroundColor",& DEFAULT_KICON_COLOR);
-  settingData.typeOfKIcon=kapp->config()->readBoolEntry("TypeOfKIcon", KNutDock::pictureKI);
+  settingData.customTDEIconColor=kapp->config()->readBoolEntry("CustomTDEIconColor",FALSE);
+  settingData.kIconBackgroundColor=kapp->config()->readColorEntry ("TDEIconBackGroundColor",& DEFAULT_KICON_COLOR);
+  settingData.typeOfTDEIcon=kapp->config()->readBoolEntry("TypeOfTDEIcon", KNutDock::pictureKI);
   settingData.typeDigitalProcessing=kapp->config()->readNumEntry("DigitalProcessingOfPointers", 2);
 
 
@@ -439,9 +439,9 @@ void KNutClient::saveConfiguration ( bool all ) {
 
   if (all) {
     kapp->config()->writeEntry ("DigitalProcessingOfPointers",settingData.typeDigitalProcessing);
-    kapp->config()->writeEntry ("TypeOfKIcon",settingData.typeOfKIcon);
-    kapp->config()->writeEntry ("KIconBackGroundColor",settingData.kIconBackgroundColor);
-    kapp->config()->writeEntry ("CustomKIconColor",(settingData.customKIconColor));
+    kapp->config()->writeEntry ("TypeOfTDEIcon",settingData.typeOfTDEIcon);
+    kapp->config()->writeEntry ("TDEIconBackGroundColor",settingData.kIconBackgroundColor);
+    kapp->config()->writeEntry ("CustomTDEIconColor",(settingData.customTDEIconColor));
     kapp->config()->writeEntry ("ToolTipFlags",(settingData.toolTipFlags));
     }
 
@@ -529,7 +529,7 @@ bool KNutClient::commitData (TQSessionManager&) {
 
 void KNutClient::upsActivate (void) {
 
-//qDebug ("KNutClient::upsActivate");
+//tqDebug ("KNutClient::upsActivate");
 
   m_mainUpsInfo.upsNet = new KNutNet( m_mainUpsInfo.record.upsAddress,m_mainUpsInfo.record.upsName,m_mainUpsInfo.record.port,0,1);
   if (m_mainUpsInfo.upsNet->getState() != KNutNet::Connected) {
@@ -677,7 +677,7 @@ void KNutClient::setActiveUpsInfo (TQString name) {
 void KNutClient::getUpsData (void) {
   int runNetError;
 
-//qDebug("KNutClient::getUpsData");
+//tqDebug("KNutClient::getUpsData");
 
   //loads values for selected variables <getUpsValues(false)>  / activate values
   if (!(runNetError=m_mainUpsInfo.upsNet->getUpsValues(false))) { // data from upsNet is ok
@@ -761,7 +761,7 @@ void KNutClient::slotTimeout (void) {
 
 
 void KNutClient::slotConnectionClosed(void) {
-//qDebug("KNutClient::slotConnectionClosed");
+//tqDebug("KNutClient::slotConnectionClosed");
 
   m_mainUpsInfo.netError = KNutNet::ConnetionClosedByServer;
 
@@ -790,7 +790,7 @@ void KNutClient::slotConnectionClosed(void) {
 void KNutClient::showStatusEvent(void) {
 
 
-//qDebug ("KNutClient::showStatusEvent");
+//tqDebug ("KNutClient::showStatusEvent");
   int myState = m_mainUpsInfo.upsNet->readStatus();
   if (myState != m_mainUpsInfo.oldState) {
 
@@ -925,7 +925,7 @@ void KNutClient::slotSetNewUPS (TQString name) {
 void KNutClient::slotPreferenceUps (void) {
 
   KNutPrefDlg* prefDlg = new KNutPrefDlg ( upsRecords, analogRecords, &settingData, m_mainUpsInfo.record.name ); // aktivujeme dialog pro preference
-  connect (prefDlg,TQT_SIGNAL(signalChangeConfig(unsigned int)),this,TQT_SLOT(slotSetConfig(unsigned int)));
+  connect (prefDlg,TQ_SIGNAL(signalChangeConfig(unsigned int)),this,TQ_SLOT(slotSetConfig(unsigned int)));
   prefDlg->exec();
   delete prefDlg;
   }
@@ -995,15 +995,15 @@ void KNutClient::slotSetConfig (unsigned int changeSetting) {
       if (m_myDock) m_myDock->changeUps();
       }
 
-    if (changeSetting & KNutPrefDlg::ChangeTypeOfKIcon) {
-      if (m_myDock) m_myDock->changeKIcon();
+    if (changeSetting & KNutPrefDlg::ChangeTypeOfTDEIcon) {
+      if (m_myDock) m_myDock->changeTDEIcon();
       }
 
-    if (changeSetting & KNutPrefDlg::ChangeCustomKIconColor) {
+    if (changeSetting & KNutPrefDlg::ChangeCustomTDEIconColor) {
       if (m_myDock) m_myDock->changeKIBColor();
       }
 
-    if (changeSetting & KNutPrefDlg::ChangeKIconBColor) {
+    if (changeSetting & KNutPrefDlg::ChangeTDEIconBColor) {
       if (m_myDock) m_myDock->changeKIBColor();
       }
 
@@ -1065,7 +1065,7 @@ void KNutClient::slotRWVars(void) {
     if (!m_mainUpsInfo.errorUpsData) {
       if (m_mainUpsInfo.upsNet->readNumberVars (KNutNet::RWVars)) {
         KNutRWVar *windowRWVars = new KNutRWVar(&m_mainUpsInfo.name,&m_mainUpsInfo.password,m_mainUpsInfo.record.userName,m_mainUpsInfo.record.password,m_mainUpsInfo.upsNet);
-        connect (windowRWVars,TQT_SIGNAL(signalChangeRWVars(TQString)),this,TQT_SLOT(slotChangeRWVars(TQString)));
+        connect (windowRWVars,TQ_SIGNAL(signalChangeRWVars(TQString)),this,TQ_SLOT(slotChangeRWVars(TQString)));
         if (windowRWVars->upsOk())  windowRWVars->exec();
         delete windowRWVars;
        }
@@ -1152,19 +1152,19 @@ void KNutClient::exitMainWindow (void) {
 void KNutClient::makeMainWindow (void) {
 
   mainWindow = new KNutMainWindow(m_listKNutEvent ,&m_mainUpsInfo, &settingData, upsRecords, analogRecords);
-  connect(mainWindow, TQT_SIGNAL(UPSChanged (TQString)), this, TQT_SLOT(slotSetNewUPS (TQString)));
-  connect(mainWindow, TQT_SIGNAL(preferenceUps()),this, TQT_SLOT(slotPreferenceUps()));
-  connect(mainWindow, TQT_SIGNAL(showUPSVars()),this, TQT_SLOT(slotPrintUPSVars()));
-  connect(mainWindow, TQT_SIGNAL(makeInstComms()),this, TQT_SLOT(slotInstComms()));
-  connect(mainWindow, TQT_SIGNAL(makeRWVars()),this, TQT_SLOT(slotRWVars()));
-  connect(mainWindow, TQT_SIGNAL(makeRefreshConnection()),this, TQT_SLOT(slotRefreshConnection()));
-  connect(mainWindow, TQT_SIGNAL(saveConf()),this, TQT_SLOT(slotSaveConf()));
+  connect(mainWindow, TQ_SIGNAL(UPSChanged (TQString)), this, TQ_SLOT(slotSetNewUPS (TQString)));
+  connect(mainWindow, TQ_SIGNAL(preferenceUps()),this, TQ_SLOT(slotPreferenceUps()));
+  connect(mainWindow, TQ_SIGNAL(showUPSVars()),this, TQ_SLOT(slotPrintUPSVars()));
+  connect(mainWindow, TQ_SIGNAL(makeInstComms()),this, TQ_SLOT(slotInstComms()));
+  connect(mainWindow, TQ_SIGNAL(makeRWVars()),this, TQ_SLOT(slotRWVars()));
+  connect(mainWindow, TQ_SIGNAL(makeRefreshConnection()),this, TQ_SLOT(slotRefreshConnection()));
+  connect(mainWindow, TQ_SIGNAL(saveConf()),this, TQ_SLOT(slotSaveConf()));
 
 
 
 
-  connect(mainWindow, TQT_SIGNAL(endApplication()), this, TQT_SLOT(slotExitApplication()));
-  connect(mainWindow, TQT_SIGNAL(destroyed()), this, TQT_SLOT(exitMainWindow()));
+  connect(mainWindow, TQ_SIGNAL(endApplication()), this, TQ_SLOT(slotExitApplication()));
+  connect(mainWindow, TQ_SIGNAL(destroyed()), this, TQ_SLOT(exitMainWindow()));
   }
 
 
@@ -1220,7 +1220,7 @@ void KNutClient::slotExitApplication(void) {
   m_upsTimer->stop();
   if (mainWindow) {
     // odpojime protoze exitMainWindow by byl vykonan az po zkonceni procedury;
-    disconnect(mainWindow, TQT_SIGNAL(destroyed()), this, TQT_SLOT(exitMainWindow()));
+    disconnect(mainWindow, TQ_SIGNAL(destroyed()), this, TQ_SLOT(exitMainWindow()));
     delete mainWindow;
     mainWindow = 0;
     }
