@@ -20,7 +20,7 @@
 
 //Od verze 3 je kapp jen odkaz na kapplication
 //Since version 3 is kapp pointer on kapplication only
-//#include <kapplication.h>
+//#include <tdeapplication.h>
 #include <kapp.h>
 
 #include <tqobject.h>
@@ -78,8 +78,8 @@ class TQTimer;
  * @version 0.7
 */
 class KNutNet : public TQObject  {
-   Q_OBJECT
-  TQ_OBJECT
+   TQ_OBJECT
+  
 public: 
 
   enum NetState {Idle, HostLookup, Connecting, Connected, ConnectError,Closing };
@@ -778,7 +778,7 @@ void upsSetType (struct upsVarDef& upsVar, const TQString name, const TQString v
 
 /**
  * @internal
- * Pro qt mensi nez 3.0.0 nemuze byt value const
+ * Pro TQt mensi nez 3.0.0 nemuze byt value const
  */
  void genStatusFlags (TQString value);
 
