@@ -47,7 +47,7 @@ class TQCheckBox;
  */
 class KNutNewUpsDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
